@@ -1787,6 +1787,14 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov | semiletov.org/tea&lt;br&gt;Support TEA on www.patreon.com/semiletov&lt;br&gt;Git: github.com/psemiletov/tea-qt&lt;br&gt;AUR: aur.archlinux.org/packages/tea-qt</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Capitalize sentences</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>GTK Bookmarks:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CTioReadOnly</name>
